#!/bin/bash
#
# Sample script, part of px-preset-sample-renumber tool.
# --Jeff Kellem, @composerjk
# https://synthmanage.com/
#
# Example Bash script to process multiple Prophet X/XL SysEx Program Data
# dump files with px-preset-sample-renumber to renumber the referenced
# sample groups.
#
# Assumptions in this example:
#    UserBankX.syx == programs/presets stored in UX, e.g., U1
#    and has at least some presets referencing sample group U8 samples.
#
# This code will create UserBank1-SampleU1.syx through UserBank4-SampleU7.syx
# renumbers any referenced U8 sample group samples to each matching SampleUx
# group x.
# For example UserBank2-SampleU5.syx will have:
#	- programs/presets in U2
#	- sample groups that were U8 in the original UserBank2.syx will
#	  now be referenced as U5 in those programs/presets.
#
for f in UserBank[1234].syx
do
	for n in U{1..7}
	do
		px-preset-sample-renumber -f U8 -t $n -o ${f%%.syx}-Sample${n}.syx $f
		done
	done
